@@ -3,7 +3,7 @@ use std::time::Instant;
 use swc_common::{
     pass::{CompilerPass, Repeated},
     util::take::Take,
-    Mark, Span, DUMMY_SP,
+    Mark, Span, Spanned, DUMMY_SP,
 };
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, Id, ModuleItemLike, StmtLike, Value};
@@ -21,7 +21,9 @@ pub(crate) fn make_number(span: Span, value: f64) -> Expr {
     Expr::Lit(Lit::Num(Number { span, value }))
 }
 
-pub trait MoudleItemExt: StmtLike + ModuleItemLike + From<Stmt> {
+pub trait MoudleItemExt:
+    StmtLike + ModuleItemLike + From<Stmt> + Spanned + std::fmt::Debug
+{
     fn as_module_decl(&self) -> Result<&ModuleDecl, &Stmt>;
 
     fn from_module_item(item: ModuleItem) -> Self;
